@@ -4,6 +4,7 @@ from .panic import Panic
 from .result_shortcut import result_shortcut
 from .to_option import to_option
 from .to_result import to_io_result, to_result
+from .typeguards import is_err, is_null, is_ok, is_some
 
 __all__ = [
     "Option",
@@ -20,4 +21,8 @@ __all__ = [
     "Panic",
     "to_io_result",
     "IOResult",
+    "is_some",
+    "is_null",
+    "is_ok",
+    "is_err",
 ]
