@@ -1,8 +1,9 @@
 from __future__ import annotations
 
 from abc import ABC, abstractmethod
+from collections.abc import Callable
 from dataclasses import dataclass
-from typing import Any, Callable, Generic, NoReturn, TypeVar, cast, overload
+from typing import Any, Generic, NoReturn, TypeVar, cast, overload
 
 from .panic import Panic
 
